@@ -1,5 +1,5 @@
-padMis.syn <- function(data, method, predictorMatrix, visitSequence,
-                       nvar, rules, rvalues, defaultMethod, contNA, smoothing, denom) {
+padMis.syn <- function(data, method, predictor.matrix, visit.sequence,
+                       nvar, rules, rvalues, default.method, cont.na, smoothing, denom) {
 
  # Function called by syn to make dummy/factor variable for missing values
  # in continuous variables. Data is augmented by columns for dummy/factor 
@@ -12,13 +12,13 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
  com.rules <- lapply(rules, paste, collapse=" | ")
  for (j in 1:nvar){
    if (yes.rules[j]){
-     No.NA[j] <- with(data,sum(data[!eval(parse(text=com.rules[[j]])),j] %in% contNA[[j]]))      
+     No.NA[j] <- with(data,sum(data[!eval(parse(text=com.rules[[j]])),j] %in% cont.na[[j]]))      
    } else {
-     No.NA[j] <- sum(data[,j] %in% contNA[[j]]) 
+     No.NA[j] <- sum(data[,j] %in% cont.na[[j]]) 
    }
  }
  No.NA    <- sapply(No.NA,function(x) x>0)
- inpred   <- apply(predictorMatrix!=0,1,any)|apply(predictorMatrix!=0,2,any)
+ inpred   <- apply(predictor.matrix!=0,1,any)|apply(predictor.matrix!=0,2,any)
  factorNA <- rep(FALSE,nvar)
 
  for(j in 1:nvar){
@@ -27,8 +27,9 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
     # augment the data with a column for the original continuous variable with 
     # missing values replaced by zeros and a column for a new factor for 
     # missing values 
-      y.0  <- ifelse(data[,j] %in% c(contNA[[j]],rvalues[[j]]),0,data[,j])
-      y.NA <- ifelse(data[,j] %in% c(contNA[[j]],rvalues[[j]]),data[,j],0)
+      nonmiscode <- 10^(nchar(round(max(data[,j],na.rm=TRUE)))+1)-1                 #BN13/11
+      y.0  <- ifelse(data[,j] %in% c(cont.na[[j]],rvalues[[j]]),0,data[,j])
+      y.NA <- ifelse(data[,j] %in% c(cont.na[[j]],rvalues[[j]]),data[,j],nonmiscode) #BN13/11 0 changed with nonmiscode
       y.NA <- addNA(y.NA,ifany=TRUE) 
       data <- cbind(data,y.0,y.NA)           
       name.0  <- paste(attr(data,"names")[j],0,sep=".")
@@ -36,16 +37,16 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
       names(data)[(ncol(data)-1):ncol(data)] <- c(name.0,name.NA)
       factorNA[(ncol(data)-1):ncol(data)] <- c(FALSE,TRUE) 
 
-    # predictorMatrix is given two extra rows and columns for the new variables
-    # rows and columns are copied from an original variable j in predictorMatrix
-      predictorMatrix <- rbind(predictorMatrix,  matrix(rep(predictorMatrix[j,], 
+    # predictor.matrix is given two extra rows and columns for the new variables
+    # rows and columns are copied from an original variable j in predictor.matrix
+      predictor.matrix <- rbind(predictor.matrix,  matrix(rep(predictor.matrix[j,], 
                                times=2),byrow=TRUE,nrow=2))
-      predictorMatrix <- cbind(predictorMatrix, matrix(rep(predictorMatrix[,j], 
+      predictor.matrix <- cbind(predictor.matrix, matrix(rep(predictor.matrix[,j], 
                                times=2),ncol=2))
     # the original variable is removed from predictors (=insert zeros) 
-      predictorMatrix[,j] <- 0
+      predictor.matrix[,j] <- 0
     # the original variable is imputed passively so its predictors can be removed as well
-      predictorMatrix[j,] <- 0
+      predictor.matrix[j,] <- 0
 
     # add methods for new variables
       method[ncol(data)-1] <- method[j]
@@ -53,7 +54,7 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
         method[ncol(data)] <- method[j]  
       } else {
         method[ncol(data)] <- ifelse(nlevels(data[,ncol(data)])==2,
-                                     defaultMethod[2],defaultMethod[3])
+                                     default.method[2],default.method[3])
       }   
     
     # pass smoothing to new variables
@@ -65,10 +66,10 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
     
     # insert the column numbers for the new variables into the visit sequence 
     # before the jth column
-      if (any(visitSequence==j)){                    
+      if (any(visit.sequence==j)){                    
         newcols <- c(ncol(data),ncol(data)-1)
-        idx <- (1:length(visitSequence))[visitSequence==j]-1
-        visitSequence <- append(visitSequence,newcols,idx)
+        idx <- (1:length(visit.sequence))[visit.sequence==j]-1
+        visit.sequence <- append(visit.sequence,newcols,idx)
       # modify method for the original variable
         method[j] <- paste0("~(ifelse(",name.0,"==0 | is.na(",name.0,
             "),as.numeric(levels(",name.NA,"))[",name.NA,"],",name.0,"))")
@@ -76,8 +77,8 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
 
     # update missing rules and values for the new variables
       if (any(rules[[j]]!="")) rules[[ncol(data)-1]] <-
-        c(rules[[j]][rules[[j]]!=""],paste(name.NA,"!=0",sep=""))
-      else rules[[ncol(data)-1]] <- paste(name.NA,"!=0",sep="") 
+        c(rules[[j]][rules[[j]]!=""],paste(name.NA,"!=",nonmiscode,sep=""))  #BN13/11
+      else rules[[ncol(data)-1]] <- paste(name.NA,"!=",nonmiscode,sep="")    #BN13/11 
       rules[[ncol(data)]]        <- rules[[j]]                      
       rules[[j]]                 <- ""
       #!BN1513 rule "year_death.NA!=0" should have only one correspnding 
@@ -89,14 +90,14 @@ padMis.syn <- function(data, method, predictorMatrix, visitSequence,
   }
    
   varnames <- dimnames(data)[[2]]  # now includes new names
-  dimnames(predictorMatrix) <- list(varnames,varnames)
+  dimnames(predictor.matrix) <- list(varnames,varnames)
   names(method) <- varnames
-  names(visitSequence) <- varnames[visitSequence]
+  names(visit.sequence) <- varnames[visit.sequence]
   return(list(data = as.data.frame(data), 
               nvar = ncol(data),
-              predictorMatrix = predictorMatrix, 
+              predictor.matrix = predictor.matrix, 
               method = method, 
-              visitSequence = visitSequence, 
+              visit.sequence = visit.sequence, 
               rules = rules,
               rvalues = rvalues,
               factorNA = factorNA,
