@@ -6,25 +6,27 @@
 
 syn <- function(data,
                 method = vector("character",length=ncol(data)),
-                visitSequence = (1:ncol(data)),
-                predictorMatrix = NULL,  
+                visit.sequence = (1:ncol(data)),
+                predictor.matrix = NULL,  
                 m = 1, 
                 k = nrow(data),
                 proper = FALSE, 
-                nlevelmax = 5,
+                minnumlevels = 5,
                 maxfaclevels = 60,
                 rules = as.list(rep("",ncol(data))),                                    
                 rvalues = as.list(rep(NA,ncol(data))),                                  
-                contNA = as.list(rep(NA,ncol(data))),
+                cont.na = as.list(rep(NA,ncol(data))),
+                semicont = as.list(rep(NA,ncol(data))),
                 event = rep(0,ncol(data)),
                 smoothing = rep("",ncol(data)), 
                 denom = rep(0,ncol(data)),
                 minbucket = 5,    
                 drop.not.used = TRUE, 
-                drop.pred.only = TRUE,                                            
-                defaultMethod = c("normrank","logreg","polyreg","polr"),
+                drop.pred.only = FALSE,                                            
+                default.method = c("normrank","logreg","polyreg","polr"),
                 diagnostics = FALSE,
-                printFlag = TRUE,
+                print.flag = TRUE,
+                seed = "sample",
                 ...
                 )
 {
@@ -37,38 +39,47 @@ syn <- function(data,
 if (all(method=="")) method="ctree"
 #else if (length(method)==1 && method=="parametric") method=rep("",dim(data)[2])
 # change vectors to lists
-if (!is.list(rules))   rules <- as.list(rules)
-if (!is.list(contNA))  contNA <- as.list(contNA)
-if (!is.list(rvalues)) rvalues <- as.list(rvalues)
+if (!is.list(rules))    rules <- as.list(rules)
+if (!is.list(cont.na))   cont.na <- as.list(cont.na)
+if (!is.list(semicont)) semicont <- as.list(semicont)
+if (!is.list(rvalues))  rvalues <- as.list(rvalues)
 
-##-----------------------check.visitSequence.syn-----------------------
+if (!is.null(attr(data,"filetype")) && attr(data,"filetype")=="sav") {
+  var.lab <- attr(data,"variable.labels")
+  val.lab <- attr(data,"label.table")
+} else {
+  var.lab <- val.lab <- NULL
+}
 
-check.visitSequence.syn <- function(setup){
 
- vis      <- setup$visitSequence
+##-----------------------check.visit.sequence.syn-----------------------
+
+check.visit.sequence.syn <- function(setup){
+
+ vis      <- setup$visit.sequence
  nvar     <- setup$nvar
  varnames <- setup$varnames
  method   <- setup$method
 
- # visitSequence can include column indices only
+ # visit.sequence can include column indices only
  # not all columns have to be given - variables
  # not in the visit sequence won't be synthesised
  
- # stop if variable in visitsequence more than once
+ # stop if variable in visit.sequence more than once
  if (any(duplicated(vis)))  stop("\n Visit sequence includes repeated variable numbers\n")
 
  # remove any visitSequnce members outside 1:nvar
  if (any(!(vis %in% 1:nvar))) {
    cat("Element(s): {",paste(vis[!(vis %in% 1:nvar)],
-       collapse=", "),"} of the 'visitSequence' removed as not valid. No such column.\n\n",sep="")
+       collapse=", "),"} of the 'visit.sequence' removed as not valid. No such column.\n\n",sep="")
    vis <- as.numeric(vis[vis %in% 1:nvar])
  }
 
- # remove event indicator(s) from visitSequence, if present
+ # remove event indicator(s) from visit.sequence, if present
  event.in.vis <- !is.na(match(vis,event))
  if (!is.null(event) & any(event.in.vis)) {
    cat("Element(s) {",paste(vis[event.in.vis],collapse=", "),
-       "} of the 'visitSequence' with method(s) {",
+       "} of the 'visit.sequence' with method(s) {",
        paste(method[vis[event.in.vis]],collapse=", "),
        "} removed because used as event indicator(s).\nAny event indicators will be synthesised along with the corresponding survival time(s). \n\n")
    vis <- vis[!event.in.vis]
@@ -101,8 +112,8 @@ check.visitSequence.syn <- function(setup){
  }
  #!---
                                                                         
- # stop if visitSequence is empty
- if (length(vis)==0) stop(paste("Seems no variables being synthesised.\nCheck parameter 'visitSequence'."))
+ # stop if visit.sequence is empty
+ if (length(vis)==0) stop(paste("Seems no variables being synthesised.\nCheck parameter 'visit.sequence'."))
 
  # All variables used in passive synthesis have to be synthesised BEFORE
  # the variables they apply to
@@ -113,22 +124,22 @@ check.visitSequence.syn <- function(setup){
      varnames[vis][j]," has/have to be synthesised BEFORE the variables they apply to.")
  }
 
- setup$visitSequence <- vis
+ setup$visit.sequence <- vis
  return(setup)
 }
-##-----------------end of--check.visitSequence.syn---------------------
+##-----------------end of--check.visit.sequence.syn---------------------
 
 
-##-----------------------check.predictorMatrix.syn---------------------
+##-----------------------check.predictor.matrix.syn---------------------
 
-check.predictorMatrix.syn <- function(setup){
- ## checks the predictorMatrix
- ## makes consistency edits of the predictorMatrix
+check.predictor.matrix.syn <- function(setup){
+ ## checks the predictor.matrix
+ ## makes consistency edits of the predictor.matrix
 
- pred     <- setup$predictorMatrix
+ pred     <- setup$predictor.matrix
  nvar     <- setup$nvar
  varnames <- setup$varnames
- vis      <- setup$visitSequence
+ vis      <- setup$visit.sequence
  method   <- setup$method
  denom     <-setup$denom                     #GRdenom new
     
@@ -144,7 +155,7 @@ check.predictorMatrix.syn <- function(setup){
  dimnames(pred)   <- list(varnames, varnames)
  diag(pred)       <- 0
 
- # select from visitSequence variables that are synthesised
+ # select from visit.sequence variables that are synthesised
  # (=method different than "")
  vis.syn <- vis
  if (!all(method=="") & length(method)>1) vis.syn <- intersect(vis,which(method!=""))
@@ -153,7 +164,7 @@ check.predictorMatrix.syn <- function(setup){
    vis.blank        <- setdiff(vis,vis.syn)
    pred[vis.blank,] <- 0
  }
- # removing predictors for variables not in visitSequence
+ # removing predictors for variables not in visit.sequence
  pred[setdiff(1:nvar,vis),] <- 0
  
  # removing predictors for variables with "sample" method
@@ -170,7 +181,7 @@ check.predictorMatrix.syn <- function(setup){
        if (denom[j]>0) pred[j,denom[j]]<-0
     }
                                                                     # to here
- # checking consistency between visitSequence and predictor matrix
+ # checking consistency between visit.sequence and predictor matrix
  # provided by a user: dropping from predictors variables that are
  # not already synthesised
 
@@ -181,15 +192,15 @@ if (length(vis)>1) {
                            0,pred[,vis.syn])
  	if(nrow(preddel)>0) cat(paste("Not synthesised predictor ",
                          varnames[vis.syn][preddel[,2]],
-                         " removed from predictorMatrix for variable ",
+                         " removed from predictor.matrix for variable ",
                          varnames[preddel[,1]],".\n",sep=""))
 
 }
-setup$predictorMatrix <- pred
- setup$visitSequence   <- vis
+setup$predictor.matrix <- pred
+ setup$visit.sequence   <- vis
  return(setup)
 }
-##-----------------end of--check.predictorMatrix.syn-------------------
+##-----------------end of--check.predictor.matrix.syn-------------------
 
 
 ##-----------------------check.method.syn------------------------------
@@ -198,11 +209,11 @@ check.method.syn <- function(setup, data, proper) {
  ## check method, set defaults if appropriate
 
  method        <- setup$method
- defaultMethod <- setup$defaultMethod
- vis           <- setup$visitSequence
+ default.method <- setup$default.method
+ vis           <- setup$visit.sequence
  nvar          <- setup$nvar
  varnames	     <- setup$varnames
- pred		       <- setup$predictorMatrix
+ pred		       <- setup$predictor.matrix
  event         <- setup$event
  denom         <- setup$denom                    #GRdenom new
 
@@ -211,7 +222,7 @@ check.method.syn <- function(setup, data, proper) {
  else has.pred<-rep(0,nvar)
 
  if(any(method=="parametric")){ # the default argument
-   # set method for first in visitsequence to "sample"
+   # set method for first in visit.sequence to "sample"
    # method[vis[1]] <- "sample"  
    # change to default methods for variables with predictors
 
@@ -219,11 +230,11 @@ check.method.syn <- function(setup, data, proper) {
 	   for(j in vis[-1]){
 	     if (has.pred[j]){
 	       y <- data[,j]
-	       if(is.numeric(y))        method[j] <- defaultMethod[1]
-	       else if(nlevels(y) == 2) method[j] <- defaultMethod[2]
-	       else if(is.ordered(y) & nlevels(y) > 2) method[j] <- defaultMethod[4]
-	       else if(nlevels(y) > 2)  method[j] <- defaultMethod[3]
-	       else if(is.logical(y))   method[j] <- defaultMethod[2]
+	       if(is.numeric(y))        method[j] <- default.method[1]
+	       else if(nlevels(y) == 2) method[j] <- default.method[2]
+	       else if(is.ordered(y) & nlevels(y) > 2) method[j] <- default.method[4]
+	       else if(nlevels(y) > 2)  method[j] <- default.method[3]
+	       else if(is.logical(y))   method[j] <- default.method[2]
 	       else if(nlevels(y)!=1) stop("Variable ",j," ",varnames[j],
 		 " type not numeric or factor.") # to prevent a constant values failing
 	     }
@@ -404,11 +415,11 @@ for(j in vis) {
 	 if (length(collmx)>0) stop("Variables ", paste(collmx,collapse=", "),
 	   " are pairwise collinear and cannot both be used in synthesis.")
  }
- setup$event           <- event
- setup$method          <- method
- setup$predictorMatrix <- pred
- setup$visitSequence   <- vis
- setup$denom           <-denom                  #GRdenom new
+ setup$event            <- event
+ setup$method           <- method
+ setup$predictor.matrix <- pred
+ setup$visit.sequence   <- vis
+ setup$denom            <- denom                  #GRdenom new
  
  return(setup)
 }
@@ -421,11 +432,11 @@ check.rules.syn <- function(setup, data) {
 
  rules      <- setup$rules
  rvalues    <- setup$rvalues
- pred       <- setup$predictorMatrix
- nvar       <- setup$nvar
+ pred       <- setup$predictor.matrix
+ nvar       <- setup$nvar                                                               
  varnames   <- setup$varnames
  method     <- setup$method
- vis        <- setup$visitSequence
+ vis        <- setup$visit.sequence
   
  # Check the syntax
  #------------------
@@ -536,12 +547,7 @@ check.rules.syn <- function(setup, data) {
  # varnames[predNAwrong[,1]]," and cannot be used as its predictor (removed).\n",sep=""),
  # "\n",sep="")
 
- # check length of missing data codes for continuous variable
-  if (length(contNA)!=nvar)
-    stop(paste("The length of 'contNA' (",length(contNA),
-     ") does not match the number of columns in the data (",nvar,").",sep=""))
-
- setup$predictorMatrix <- pred
+ setup$predictor.matrix <- pred
 
  return(setup)
 }
@@ -555,6 +561,12 @@ check.rules.syn <- function(setup, data) {
 
  call <- match.call()
  nvar <- ncol(data)
+ if (!is.na(seed) & seed=="sample") {
+   seed <- sample.int(1000,1)
+   cat("No seed has been provided and it has been set to ", 
+     seed,".\n\n", sep="")
+ }
+ if (!is.na(seed)) set.seed(seed)
 
  if(!(is.matrix(data) | is.data.frame(data)))
     stop("Data should be a matrix or data frame.")
@@ -567,7 +579,7 @@ check.rules.syn <- function(setup, data) {
                                   " and should be of length ",nvar,".",sep="")
                               
  # S U B S A M P L E   S I Z E
- if(k!=nrow(data)) {
+ if(k!=nrow(data) & print.flag==TRUE) {
   # if (k > nrow(data)) {
   #   cat("Warning: Subpopulation size (k=",k,") cannot be greater than the population size (",
   #       nrow(data),").\n","Synthetic data sets of same size as data will be produced.\n\n",sep="")
@@ -583,9 +595,9 @@ check.rules.syn <- function(setup, data) {
  if (length(method)==1){
    if(is.passive(method)) stop("Cannot have a passive syhthesising method for every column.")
    method <- rep(method, nvar)
-   method[visitSequence[1]] <- "sample" # set 1st in visit seq to "sample"
-   # set method to "" for vars not in visitSequence
-   method[setdiff(1:nvar,visitSequence)] <- ""
+   method[visit.sequence[1]] <- "sample" # set 1st in visit seq to "sample"
+   # set method to "" for vars not in visit.sequence
+   method[setdiff(1:nvar,visit.sequence)] <- ""
  }
  
  # if user specifies multiple methods, check the length of the argument
@@ -594,44 +606,59 @@ check.rules.syn <- function(setup, data) {
     ") does not match the number of columns in the data (",nvar,").",sep=""))
 
  # P R E D I C T O R   M A T R I X
- if(!is.null(predictorMatrix)){
-   if (!is.matrix(predictorMatrix)) {
-     stop("Argument 'predictorMatrix' is not a matrix.")
-   } else if (nvar!=nrow(predictorMatrix)| nvar!=ncol(predictorMatrix))
-     stop(paste("The 'predictorMatrix' has ",nrow(predictorMatrix)," row(s) and ",ncol(predictorMatrix),
+ if(!is.null(predictor.matrix)){
+   if (!is.matrix(predictor.matrix)) {
+     stop("Argument 'predictor.matrix' is not a matrix.")
+   } else if (nvar!=nrow(predictor.matrix)| nvar!=ncol(predictor.matrix))
+     stop(paste("The 'predictor.matrix' has ",nrow(predictor.matrix)," row(s) and ",ncol(predictor.matrix),
           " column(s). \nBoth should match the number of columns in the data (",nvar,").",sep=""))
  }
 
  data     <- as.data.frame(data)
  varnames <- dimnames(data)[[2]]
 
+ # C O N T I N O U S  V A R S  W I T H  M I S S I N G  D A T A  C O D E S
+ # S E M I - C O N T I N O U S  V A R S 
+ # check length of missing data codes for continuous variable
+ if (length(cont.na)!=nvar)                                                               #BN13/11 moved from check rules
+   stop(paste("The length of 'cont.na' (",length(cont.na),                                 #BN13/11 moved from check rules
+              ") does not match the number of columns in the data (",nvar,").",sep=""))  #BN13/11 moved from check rules
+ if (length(semicont)!=nvar)                                                             #BN13/11
+  stop(paste("The length of 'semicont' (",length(semicont),                              #BN13/11   
+             ") does not match the number of columns in the data (",nvar,").",sep=""))   #BN13/11     
+ # combine cont.na and semicont lists  
+ cont.na.ini <- cont.na
+ cont.na <- mapply(c, cont.na, semicont, SIMPLIFY=FALSE)
+ cont.na <- lapply(cont.na, unique)
+
+
  # Perform various validity checks on the specified arguments
- setup <- list(visitSequence = visitSequence,
+ setup <- list(visit.sequence = visit.sequence,
                method = method,
-               defaultMethod = defaultMethod,
-               predictorMatrix = predictorMatrix,
+               default.method = default.method,
+               predictor.matrix = predictor.matrix,
                nvar = nvar,
                varnames = varnames, 
                rules = rules,
                rvalues = rvalues,
-               contNA = contNA,                                         
+               cont.na = cont.na,                                         
                event = event,
-               denom=denom)                   #GRdenom new
+               denom = denom)                   #GRdenom new
               
- setup <- check.visitSequence.syn(setup)
- setup <- check.predictorMatrix.syn(setup)
+ setup <- check.visit.sequence.syn(setup)
+ setup <- check.predictor.matrix.syn(setup)
 
 
  # C H A N G E  D A T A  T Y P E  &  M O D I F Y  F A C T O R  L E V E L S
 #---
  # apply only if in predictor matrix 
                                                                                # GR added condition and else
- if (!is.null(setup$predictorMatrix) & sum(setup$predictorMatrix>0)) {
-             inpred   <- apply(setup$predictorMatrix!=0,1,any)*(!(method %in% c("","sample") )) |                # GR added to allow null methods not affected
-             apply(setup$predictorMatrix!=0,2,any)  # if anywhere in predictorMatrix
+ if (!is.null(setup$predictor.matrix) & sum(setup$predictor.matrix>0)) {
+             inpred   <- apply(setup$predictor.matrix!=0,1,any)*(!(method %in% c("","sample") )) |                # GR added to allow null methods not affected
+             apply(setup$predictor.matrix!=0,2,any)  # if anywhere in predictor.matrix
         }
   else {
-    inpred<-rep(FALSE,sqrt(length(setup$predictorMatrix)))
+    inpred<-rep(FALSE,sqrt(length(setup$predictor.matrix)))
   }
  notevent <- is.na(match(1:nvar,setup$event))       # if not in event list
 
@@ -643,22 +670,22 @@ check.rules.syn <- function(setup, data) {
        " have been changed from character to factor.\n",sep=" ")
    for (j in (1:nvar)[chartofac]) data[,j] <- as.factor(data[,j]) 
  }
- # Changing numeric variables with fewer than 'nlevelmax' into factors
+ # Changing numeric variables with fewer than 'minnumlevels' into factors
  #  Default for this now set to 5, 20 too many as picked up months
  #  Also only need to do this if variable in predictionMatrix
  #  and any inappropriate methods are changed to the default for factors
  nlevel      <- sapply(data, function(x) length(table(x)))
  ifnum       <- sapply(data, is.numeric)
- vartofactor <- which(nlevel<=nlevelmax & ifnum & inpred & notevent)
+ vartofactor <- which(nlevel<=minnumlevels & ifnum & inpred & notevent)
  for (j in vartofactor) data[,j] <- as.factor(data[,j])
  if (length(vartofactor)>0) {
    cat("Variable(s): ",paste0(varnames[vartofactor],collapse=", "),
-       "numeric but with fewer than", nlevelmax,"levels turned into factor(s).\n\n",sep=" ")
+       "numeric but with fewer than", minnumlevels,"levels turned into factor(s).\n\n",sep=" ")
    for (j in vartofactor) {
      if (setup$method[j] %in% c("norm","norm.proper",
                                 "normrank","normrank.proper")) {
-       if (nlevels[j]==2) setup$method[j] <- defaultMethod[2]
-       else setup$method[j] <- defaultMethod[3]
+       if (nlevels[j]==2) setup$method[j] <- default.method[2]
+       else setup$method[j] <- default.method[3]
   	   cat("Method for ",varnames[j]," changed to ",setup$method[j],"\n\n")
      }
      }
@@ -670,7 +697,7 @@ check.rules.syn <- function(setup, data) {
    data[,j] <- addNA(data[,j],ifany=TRUE)
  } 
 
- # Identify any factors with > maxfaclevels levels that are in visitSequence
+ # Identify any factors with > maxfaclevels levels that are in visit.sequence
  too.many.levels <- sapply(data, function(x) length(levels(x))) > maxfaclevels
  if (any(inpred & too.many.levels)) {
    cat("Factor(s) with more than",maxfaclevels,"levels:",
@@ -684,32 +711,32 @@ check.rules.syn <- function(setup, data) {
  if (any(rules!="")) setup <- check.rules.syn (setup, data)
 
  method          <- setup$method
- predictorMatrix <- setup$predictorMatrix
- visitSequence   <- setup$visitSequence
+ predictor.matrix <- setup$predictor.matrix
+ visit.sequence   <- setup$visit.sequence
  event           <- setup$event
  rules           <- setup$rules
  rvalues         <- setup$rvalues
- contNA          <- setup$contNA
- defaultMethod   <- setup$defaultMethod
+ cont.na          <- setup$cont.na
+ default.method   <- setup$default.method
  denom           <- setup$denom                       #GRdenom new
 
  # Not used variables are identified and dropped if drop.not.used==T
  # reclculate inpred & notevent in case they have changed after
  # check.method and check.data
- if (sum(predictorMatrix)>0){                            # GR condition added
-   inpred      <- apply(predictorMatrix!=0,1,any) | apply(predictorMatrix!=0,2,any) # if anywhere in predictorMatrix
-	 ispredictor <- apply(predictorMatrix!=0,2,any)    # if used as predictor
+ if (sum(predictor.matrix)>0){                            # GR condition added
+   inpred      <- apply(predictor.matrix!=0,1,any) | apply(predictor.matrix!=0,2,any) # if anywhere in predictor.matrix
+	 ispredictor <- apply(predictor.matrix!=0,2,any)    # if used as predictor
  }
- else inpred<-ispredictor<-rep( 0,sqrt( length(predictorMatrix) ) ) 
+ else inpred<-ispredictor<-rep( 0,sqrt( length(predictor.matrix) ) ) 
 
- notinvs     <- is.na(match(1:nvar,visitSequence)) # if not in visitSequence
+ notinvs     <- is.na(match(1:nvar,visit.sequence)) # if not in visit.sequence
  notsynth    <- notinvs | (!notinvs & method=="")  # if not synthesised
  notevent    <- is.na(match(1:nvar,event))         # if not in event list
 
  # identify columns not used as events or predictors or in visitSequnce
  out <- !inpred & notevent & notsynth
 
- if (any(out)) {
+ if (any(out) & print.flag==TRUE) {
    cat("Variable(s):",paste0(varnames[out],collapse=", "),
        "not synthesised or used in prediction.\n",sep=" ")
    if (drop.not.used==T) cat("The variable(s) will be removed from data and not saved in synthesised data.\n\n")
@@ -721,9 +748,9 @@ check.rules.syn <- function(setup, data) {
    if(sum(!out)==0) stop("No variables left to be synthesised") ######to stop if all data excluded 
    newnumbers       <- rep(0,nvar)
    newnumbers[!out] <- 1:sum(!out)
-   visitSequence    <- newnumbers[visitSequence]
-   visitSequence    <- visitSequence[!visitSequence==0]
-   predictorMatrix  <- predictorMatrix[!out,!out]
+   visit.sequence    <- newnumbers[visit.sequence]
+   visit.sequence    <- visit.sequence[!visit.sequence==0]
+   predictor.matrix  <- predictor.matrix[!out,!out]
    event[event!=0]  <- newnumbers[event[event!=0]]
    event            <- event[!out]
    data             <- data[,!out]
@@ -737,42 +764,49 @@ check.rules.syn <- function(setup, data) {
   	 if (cl=="character") data[,1]<-as.character(data[,1])
   	 names(data)<-varnames
    }
-   contNA           <- contNA[!out]
+   cont.na           <- cont.na[!out]
+   cont.na.ini        <- cont.na.ini[!out]        #BN13/11  
+   semicont         <- semicont[!out]         #BN13/11  
    rules            <- rules[!out]
    rvalues          <- rvalues[!out]
+   var.lab          <- var.lab[!out]
+   val.lab          <- val.lab[!out]
+   
    # recalculate these
-   if (sum(predictorMatrix>0)) {                                 # GR condition added
-	   inpred <- apply(predictorMatrix!=0,1,any) |
-	             apply(predictorMatrix!=0,2,any)      # if anywhere in predictorMatrix
-	   ispredictor <- apply(predictorMatrix!=0,2,any) # if used as predictor
+   if (sum(predictor.matrix>0)) {                                 # GR condition added
+	   inpred <- apply(predictor.matrix!=0,1,any) |
+	             apply(predictor.matrix!=0,2,any)      # if anywhere in predictor.matrix
+	   ispredictor <- apply(predictor.matrix!=0,2,any) # if used as predictor
    }
-   else inpred <- ispredictor<-rep(0,sqrt(length(predictorMatrix))) 
+   else inpred <- ispredictor<-rep(0,sqrt(length(predictor.matrix))) 
 
-   notinvs  <- is.na(match(1:nvar,visitSequence))  # if not in visitSequence
+   notinvs  <- is.na(match(1:nvar,visit.sequence))  # if not in visit.sequence
    notsynth <- notinvs | (!notinvs & method=="")   # if not synthesised
    notevent <- is.na(match(1:nvar,event))          # if not in event list
  }
 
  # Print out info on variables not synthesised but used in prediction
- pred_not_syn <- (ispredictor & notsynth)
- if (sum(pred_not_syn )>0) {
+ pred.not.syn <- (ispredictor & notsynth)
+ if (sum(pred.not.syn )>0 & drop.pred.only==FALSE) pred.not.syn[pred.not.syn==TRUE] <- FALSE
+ 
+ if (sum(pred.not.syn )>0 & print.flag==TRUE) {
    cat("Variable(s):", paste0(varnames[ispredictor & notsynth],collapse=", "),
        "used as predictors but not synthesised.\n",sep=" ")
-   if (drop.pred.only==T) cat("The variable(s) will not be saved with the synthesised data.\n\n")
-   else  {
+   if (drop.pred.only==T) {
+     cat("The variable(s) will not be saved with the synthesised data.\n\n")
+   } else {
      cat("CAUTION: The synthesised data will contain the variable(s) unchanged.\n\n")
-     pred_not_syn[pred_not_syn==TRUE]<-FALSE
    }
  } 
                                                       #  GR condition added
- if (sum(predictorMatrix)>0) {
-	 pm <- padMis.syn(data, method, predictorMatrix, visitSequence,
-			   nvar, rules, rvalues, defaultMethod, contNA, smoothing, denom)
+ if (sum(predictor.matrix)>0) {
+	 pm <- padMis.syn(data, method, predictor.matrix, visit.sequence,
+			   nvar, rules, rvalues, default.method, cont.na, smoothing, denom)
 
 	 # Pad the Syhthesis model with dummy variables for the factors
-	 # p <- padModel.syn(data, method, predictorMatrix, visitSequence,
+	 # p <- padModel.syn(data, method, predictor.matrix, visit.sequence,
 	 #                   nvar, rules, rvalues)
-	 p  <- padModel.syn(pm$data, pm$method, pm$predictorMatrix, pm$visitSequence,
+	 p  <- padModel.syn(pm$data, pm$method, pm$predictor.matrix, pm$visit.sequence,
 			   pm$nvar, pm$rules, pm$rvalues, pm$factorNA, pm$smoothing, pm$denom)
    
    if (k != dim(data)[1]){
@@ -783,15 +817,15 @@ check.rules.syn <- function(setup, data) {
  }
  else {p <- list(data = data,                             #  GR this added
               syn = data,
-              predictorMatrix = predictorMatrix, 
+              predictor.matrix = predictor.matrix, 
               method = method, 
-              visitSequence = visitSequence, 
+              visit.sequence = visit.sequence, 
               rules = rules,
               rvalues = rvalues, 
-              event=event,                  #GRdenom new
-              denom=denom,                  #GRdenom new
+              event = event,                  #GRdenom new
+              denom = denom,                  #GRdenom new
               categories = NULL,
-              smoothing=smoothing)         
+              smoothing = smoothing)         
  }
 
  if (m > 0) {
@@ -804,36 +838,40 @@ check.rules.syn <- function(setup, data) {
  }
  else syn <- NULL
 
- syn <- sampler.syn(p, data, m, syn, visitSequence, rules, rvalues, 
-                    event, proper, minbucket, printFlag, k, pred_not_syn)
+ syn <- sampler.syn(p, data, m, syn, visit.sequence, rules, rvalues, 
+                    event, proper, minbucket, print.flag, k, pred.not.syn)
  if (m==1) syn <- syn[[1]]
 
 #-----------------------------------------------------------------------
 # restore the original NA's in the data
-# for(j in p$visitSequence) p$data[(!r[,j]),j] <- NA
+# for(j in p$visit.sequence) p$data[(!r[,j]),j] <- NA
   
  names(method)        <- varnames
- names(visitSequence) <- varnames[visitSequence]
+ names(visit.sequence) <- varnames[visit.sequence]
 
  # save, and return, but don't return data
  syndsobj <- list(call = call,
                  m = m,
                  syn = syn,
                  method = method,
-                 visitSequence = visitSequence,
-                 predictorMatrix = predictorMatrix,
+                 visit.sequence = visit.sequence,
+                 predictor.matrix = predictor.matrix,
                  event = event,
-                 smoothing=smoothing,
-                 denom=denom,                  #GRdenom new
+                 smoothing = smoothing,
+                 denom = denom,                  #GRdenom new
                  minbucket = minbucket,
                  proper = proper,
                  n = nrow(data),
                  k = k,
                  rules = rules,
                  rvalues = rvalues,
-                 contNA = contNA,
+                 cont.na = cont.na.ini,             #BN13/11
+                 semicont = semicont,            #BN13/11
                  drop.not.used = drop.not.used,
-                 drop.pred.only = drop.pred.only)
+                 drop.pred.only = drop.pred.only,
+                 seed = seed,
+                 var.lab = var.lab,
+                 val.lab = val.lab)
  if (diagnostics) syndsobj <- c(syndsobj, list(pad = p))
  class(syndsobj) <- "synds"
  return(syndsobj)
